@@ -43,10 +43,11 @@ them directly.
 
 # from python >= 2.3
 from datetime import datetime, timedelta, time, date, tzinfo
-from types import IntType, StringType, UnicodeType, TupleType, ListType
+from types import TupleType, ListType
 SequenceTypes = [TupleType, ListType]
 import re
 import time as _time
+import binascii
 
 # from this package
 from icalendar.caselessdict import CaselessDict
@@ -81,6 +82,14 @@ class vBinary:
     >>> b = vBinary('txt')
     >>> b.params
     Parameters({'VALUE': 'BINARY', 'ENCODING': 'BASE64'})
+
+    Long data should not have line breaks, as that would interfere
+    >>> x = 'a'*99
+    >>> vBinary(x).ical() == 'YWFh' * 33
+    True
+    >>> vBinary.from_ical('YWFh' * 33) == 'a' * 99
+    True
+    
     """
 
     def __init__(self, obj):
@@ -91,7 +100,7 @@ class vBinary:
         return "vBinary(%s)" % str.__repr__(self.obj)
 
     def ical(self):
-        return self.obj.encode('base-64')[:-1]
+        return binascii.b2a_base64(self.obj)[:-1]
 
     def from_ical(ical):
         "Parses the data format from ical text format"
@@ -124,9 +133,10 @@ class vBoolean(int):
     True
     """
 
-    def __init__(self, *args, **kwargs):
-        int.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vBoolean, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def ical(self):
         if self:
@@ -163,9 +173,10 @@ class vCalAddress(str):
     'MAILTO:maxm@mxm.dk'
     """
 
-    def __init__(self, *args, **kwargs):
-        str.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vCalAddress, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def __repr__(self):
         return u"vCalAddress(%s)" % str.__repr__(self)
@@ -214,7 +225,7 @@ class FixedOffset(tzinfo):
         return ZERO
 
 
-class UTC(tzinfo):
+class Utc(tzinfo):
     """UTC tzinfo subclass"""
 
     def utcoffset(self, dt):
@@ -225,7 +236,7 @@ class UTC(tzinfo):
 
     def dst(self, dt):
         return ZERO
-UTC = UTC()
+UTC = Utc()
 
 class LocalTimezone(tzinfo):
     """
@@ -298,7 +309,6 @@ class vDatetime:
 
     def ical(self):
         if self.dt.tzinfo:
-            offset = self.dt.tzinfo.utcoffset(datetime.now())
             utc_time = self.dt - self.dt.tzinfo.utcoffset(datetime.now())
             return utc_time.strftime("%Y%m%dT%H%M%SZ")
         return self.dt.strftime("%Y%m%dT%H%M%S")
@@ -350,7 +360,7 @@ class vDate:
         if not isinstance(dt, date):
             raise ValueError('Value MUST be a date instance')
         self.dt = dt
-        self.params = Parameters()
+        self.params = Parameters(dict(value='DATE'))
 
     def ical(self):
         return self.dt.strftime("%Y%m%d")
@@ -401,7 +411,7 @@ class vDuration:
     >>> vDuration(timedelta(days=1, hours=5)).ical()
     'P1DT5H'
     >>> vDuration(timedelta(hours=-5)).ical()
-    '-P1DT19H'
+    '-PT5H'
     >>> vDuration(timedelta(days=-1, hours=-5)).ical()
     '-P1DT5H'
 
@@ -489,9 +499,10 @@ class vFloat(float):
     '42.0'
     """
 
-    def __init__(self, *args, **kwargs):
-        float.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vFloat, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def ical(self):
         return str(self)
@@ -520,9 +531,10 @@ class vInt(int):
     ValueError: Expected int, got: 1s3
     """
 
-    def __init__(self, *args, **kwargs):
-        int.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vInt, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def ical(self):
         return str(self)
@@ -547,7 +559,7 @@ class vDDDTypes:
     <type 'datetime.datetime'>
 
     >>> repr(vDDDTypes.from_ical('20010101T123000Z'))[:65]
-    'datetime.datetime(2001, 1, 1, 12, 30, tzinfo=<icalendar.prop.UTC '
+    'datetime.datetime(2001, 1, 1, 12, 30, tzinfo=<icalendar.prop.Utc '
 
     >>> d = vDDDTypes.from_ical('20010101')
     >>> type(d)
@@ -574,6 +586,9 @@ class vDDDTypes:
                 wrong_type_used = 0
         if wrong_type_used:
             raise ValueError ('You must use datetime, date or timedelta')
+        if isinstance(dt, date):
+            self.params = Parameters(dict(value='DATE'))
+
         self.dt = dt
 
     def ical(self):
@@ -585,7 +600,7 @@ class vDDDTypes:
         elif isinstance(dt, timedelta):
             return vDuration(dt).ical()
         else:
-            raise ValueEror ('Unknown date type')
+            raise ValueError('Unknown date type')
 
     def from_ical(ical):
         "Parses the data format from ical text format"
@@ -825,8 +840,8 @@ class vWeekday(str):
     week_days = CaselessDict({"SU":0, "MO":1, "TU":2, "WE":3,
                               "TH":4, "FR":5, "SA":6})
 
-    def __init__(self, *args, **kwargs):
-        str.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vWeekday, cls).__new__(cls, *args, **kwargs)
         match = WEEKDAY_RULE.match(self)
         if match is None:
             raise ValueError, 'Expected weekday abbrevation, got: %s' % self
@@ -838,6 +853,7 @@ class vWeekday(str):
             raise ValueError, 'Expected weekday abbrevation, got: %s' % self
         self.relative = relative and int(relative) or None
         self.params = Parameters()
+        return self
 
     def ical(self):
         return self.upper()
@@ -878,11 +894,12 @@ class vFrequency(str):
         "YEARLY":"YEARLY",
     })
 
-    def __init__(self, *args, **kwargs):
-        str.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vFrequency, cls).__new__(cls, *args, **kwargs)
         if not self in vFrequency.frequencies:
             raise ValueError, 'Expected frequency, got: %s' % self
         self.params = Parameters()
+        return self
 
     def ical(self):
         return self.upper()
@@ -1058,9 +1075,10 @@ class vText(unicode):
 
     encoding = 'utf-8'
 
-    def __init__(self, *args, **kwargs):
-        unicode.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vText, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def escape(self):
         """
@@ -1117,9 +1135,10 @@ class vTime(time):
     ValueError: Expected time, got: 263000
     """
 
-    def __init__(self, *args, **kwargs):
-        time.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vTime, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def ical(self):
         return self.strftime("%H%M%S")
@@ -1148,9 +1167,10 @@ class vUri(str):
     'http://www.example.com/'
     """
 
-    def __init__(self, *args, **kwargs):
-        str.__init__(self, *args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        self = super(vUri, cls).__new__(cls, *args, **kwargs)
         self.params = Parameters()
+        return self
 
     def ical(self):
         return str(self)
